(*
 * This file is part of Barista.
 * Copyright (C) 2007-2010 Xavier Clerc.
 *
 * Barista is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Barista is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *)

(** This module defines a class loader that allows easy access and loading
    of classes. *)


type t
(** Represents a class loader, that is barely a map from class names (in
   external form) to their definitions. *)

type error =
  | Unable_to_load of Utils.utf8 * (string option)
  | Already_defined

exception Exception of error
(** Exception to be raised when a function of this module fails.  *)

val string_of_error : error -> string
(** Converts the passed error into a string. *)

val make : ClassPath.t -> t
(** Constructs a class loader from a class path that will be used to load
   classes. The returned class loader contains no class definition. *)

val find : t -> Utils.utf8 -> ClassDefinition.t
(** [find cl cn] returns the class definition for the class named [cn] (in
   external form) using class loader [cl].
   Raises [Exception] if such a class has not alredy been loaded and cannot
   be loaded. *)

val add : t -> ClassDefinition.t -> unit
(** [add cl cd] adds the class [cd] to the class loader [cl].
   Raises [Exception] if a class with the same name has already been loaded. *)
