(*
 * This file is part of Barista.
 * Copyright (C) 2007-2010 Xavier Clerc.
 *
 * Barista is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Barista is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *)

(** This module provides abstraction over class path elements. *)


type t
(** The type of class paths.*)

type error =
  | Unable_to_open_archive of string
  | Does_not_exist of string
  | Class_not_found of string

exception Exception of error
(** Exception to be raised when a function of this module fails.  *)

val string_of_error : error -> string
(** Converts the passed error into a string. *)

val make_of_string : string -> t
(** Constructs a class path from a string, the colon being used as a separator
    between class path elements.
    Raises [Exception] if a class path element does not exists or if an
    archive cannot be opened. *)

val open_stream : t -> string -> InputStream.t
(** [open_stream cp cn] returns the stream for class whose fully qualified name
    is [cn], search class path [cp].
    Raises [Exception] if the passed class is not found in the given class
    path. *)

val close : t -> unit
(** Closes all underlying archives, subsequent tries to read from such archives
    will hence fail. Silently fails if an archive fails to close. *)
