(*
 * This file is part of Barista.
 * Copyright (C) 2007-2010 Xavier Clerc.
 *
 * Barista is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Barista is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *)

(** This module provides utility functions for code manipulation. *)


val remove_dead_code : ('a, 'b) ControlFlow.graph -> ('a, 'b) ControlFlow.graph
(** [remove_dead_code g] returns [g] without the vertices that cannot be
    reached from the root. *)

val flatten_graph : ('a, 'b) ControlFlow.graph -> Instruction.t list * (Utils.u2 * Utils.u2 * Utils.u2 * Name.for_class option) list * (int32 * 'a, 'b) ControlFlow.graph
(** [flatten_graph g] returns a [l, e, g'] triple where [g'] is [g] labeled with code offsets
    corresponding to the instruction list [l]. [e] is the exception table for [l]. *)

val compute_stack_infos : [ `Array_type of Descriptor.array_type | `Class_or_interface of Name.for_class ] StackState.unifier -> (int32, 'a) ControlFlow.graph -> StackState.t -> Utils.u2 * Utils.u2 * Attribute.stack_map_frame list
(** [compute_stack_infos u g s] returns [max_stack, max_locals, stack_map_frame]
    for the method whose control flow graph [g] and initial stack state [s] are passed.
    The [int32] values labelling the vertices are the offsets of the related instructions
    blocks. The function [u] is used to unify stack states.

    Raises [StackState.Exception] if the passed instruction lists associated with
    the graph vertices are incoherent. *)
