(*
 * This file is part of Barista.
 * Copyright (C) 2007-2010 Xavier Clerc.
 *
 * Barista is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Barista is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *)

open Utils


(* Java constants *)

let magic_number = 0x0CAFEBABEL


(* String constants *)

(* Attribute-related strings *)

let attr_annotation_default = utf8_of_string "AnnotationDefault"

let attr_code = utf8_of_string "Code"

let attr_constant_value = utf8_of_string "ConstantValue"

let attr_deprecated = utf8_of_string "Deprecated"

let attr_enclosing_method = utf8_of_string "EnclosingMethod"

let attr_exceptions = utf8_of_string "Exceptions"

let attr_inner_classes = utf8_of_string "InnerClasses"

let attr_line_number_table = utf8_of_string "LineNumberTable"

let attr_local_variable_table = utf8_of_string "LocalVariableTable"

let attr_local_variable_type_table = utf8_of_string "LocalVariableTypeTable"

let attr_runtime_invisible_annotations = utf8_of_string "RuntimeInvisibleAnnotations"

let attr_runtime_invisible_parameter_annotations = utf8_of_string "RuntimeInvisibleParameterAnnotations"

let attr_runtime_visible_annotations = utf8_of_string "RuntimeVisibleAnnotations"

let attr_runtime_visible_parameter_annotations = utf8_of_string "RuntimeVisibleParameterAnnotations"

let attr_signature = utf8_of_string "Signature"

let attr_source_debug_extension = utf8_of_string "SourceDebugExtension"

let attr_source_file = utf8_of_string "SourceFile"

let attr_stack_map_table = utf8_of_string "StackMapTable"

let attr_synthetic = utf8_of_string "Synthetic"

let attr_all = [ attr_annotation_default;
                 attr_code;
                 attr_constant_value;
                 attr_deprecated;
                 attr_enclosing_method;
                 attr_exceptions;
                 attr_inner_classes;
                 attr_line_number_table;
                 attr_local_variable_table;
                 attr_local_variable_type_table;
                 attr_runtime_invisible_annotations;
                 attr_runtime_invisible_parameter_annotations;
                 attr_runtime_visible_annotations;
                 attr_runtime_visible_parameter_annotations;
                 attr_signature;
                 attr_source_debug_extension;
                 attr_source_file;
                 attr_stack_map_table ;
                 attr_synthetic ]

(* Miscellaneous strings *)

let class_constructor = utf8_of_string "<init>"

let class_initializer = utf8_of_string "<clinit>"

let empty_utf8 = utf8_of_string ""

let java_lang_Object = utf8_of_string "java/lang/Object"


(* Character constants *)

(* Capital letters *)

let capital_b = uchar_of_char 'B'

let capital_c = uchar_of_char 'C'

let capital_d = uchar_of_char 'D'

let capital_f = uchar_of_char 'F'

let capital_i = uchar_of_char 'I'

let capital_j = uchar_of_char 'J'

let capital_l = uchar_of_char 'L'

let capital_s = uchar_of_char 'S'

let capital_t = uchar_of_char 'T'

let capital_v = uchar_of_char 'V'

let capital_z = uchar_of_char 'Z'

(* Small letters *)

let small_c = uchar_of_char 'c'

let small_e = uchar_of_char 'e'

let small_s = uchar_of_char 's'

(* Digits *)

let digits = List.map uchar_of_char ['0'; '1'; '2'; '3'; '4';
                                     '5'; '6'; '7'; '8'; '9'  ]

(* Special characters *)

let at_character = uchar_of_char '@'

let back_slash = uchar_of_char '\\'

let circonflex = uchar_of_char '^'

let closing_parenthesis = uchar_of_char ')'

let closing_square_bracket = uchar_of_char ']'

let colon = uchar_of_char ':'

let comma = uchar_of_char ','

let dollar = uchar_of_char '$'

let dot = uchar_of_char '.'

let greater_than = uchar_of_char '>'

let lower_than = uchar_of_char '<'

let minus = uchar_of_char '-'

let opening_parenthesis = uchar_of_char '('

let opening_square_bracket = uchar_of_char '['

let plus = uchar_of_char '+'

let quote = uchar_of_char '"'

let semi_colon = uchar_of_char ';'

let sharp = uchar_of_char '#'

let slash = uchar_of_char '/'

let space = uchar_of_char ' '

let star = uchar_of_char '*'

let tabulation = uchar_of_char '\t'

let underscore = uchar_of_char '_'
