/*
 * This file is part of Barista.
 * Copyright (C) 2007-2010 Xavier Clerc.
 *
 * Barista is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * Barista is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package tests;

import java.util.Collections;
import java.util.LinkedList;
import java.util.List;

import static java.util.Arrays.asList;

import fr.x9c.barista.api.*;

public final class Common {

    public static List<Descriptor> descs(Descriptor... l) {
	final List<Descriptor> res = new LinkedList<Descriptor>();
	for (Descriptor d : l) {
	    res.add(d);
	}
	return res;
    }

    public static Method compileMethod(final List<AccessFlag> qualifiers,
				       final String name,
				       final Descriptor ret,
				       final List<Descriptor> parameters,
				       final int maxStack,
				       final int maxLocals,
				       final List<Attribute.ExceptionTableElement> exceptionsTable,
				       final List<? extends Attribute> attributes,
				       final List<? extends Attribute> methAttributes,
				       final List<? extends Instruction> instructions) {
	final Attribute.CodeValue code =
	    new Attribute.CodeValue(maxStack,
				    maxLocals,
				    instructions,
				    exceptionsTable,
				    attributes);
	final List<Attribute> attrs = new LinkedList<Attribute>();
	attrs.add(new Attribute.Code(code));
	attrs.addAll(methAttributes);
	return new Method(qualifiers, name, ret, parameters, attrs);
    }

    public static Method compileMethod(final List<? extends Instruction> instructions) {
	return compileMethod(asList(AccessFlag.Public, AccessFlag.Static),
			     "main",
			     Descriptor.VOID,
			     descs(new Descriptor.Array(new Descriptor.Class("java.lang.String"))),
			     4,
			     4,
			     Collections.<Attribute.ExceptionTableElement>emptyList(),
			     Collections.<Attribute>emptyList(),
			     Collections.<Attribute>emptyList(),
			     instructions);
    }

    public static Method compileConstructor(final List<AccessFlag> qualifiers,
					    final List<Descriptor> parameters,
					    final int maxStack,
					    final int maxLocals,
					    final List<Attribute.ExceptionTableElement> exceptionsTable,
					    final List<? extends Attribute> attributes,
					    final List<? extends Instruction> instructions) {
	final Attribute.CodeValue code =
	    new Attribute.CodeValue(maxStack,
				    maxLocals,
				    instructions,
				    exceptionsTable,
				    attributes);
	return new Method(qualifiers, parameters, Collections.<Attribute>singletonList(new Attribute.Code(code)));
    }

    public static Method compileConstructor(final List<? extends Instruction> instructions) {
	return compileConstructor(asList(AccessFlag.Public),
				  Collections.<Descriptor>emptyList(),
				  4,
				  4,
				  Collections.<Attribute.ExceptionTableElement>emptyList(),
				  Collections.<Attribute>emptyList(),
				  instructions);
    }

    public static Method compileInitializer(final boolean strict,
					    final int maxStack,
					    final int maxLocals,
					    final List<Attribute.ExceptionTableElement> exceptionsTable,
					    final List<? extends Attribute> attributes,
					    final List<? extends Instruction> instructions) {
	final Attribute.CodeValue code =
	    new Attribute.CodeValue(maxStack,
				    maxLocals,
				    instructions,
				    exceptionsTable,
				    attributes);
	return new Method(strict, Collections.<Attribute>singletonList(new Attribute.Code(code)));
    }

    public static Method compileInitializer(final List<? extends Instruction> instructions) {
	return compileInitializer(false,
				  4,
				  4,
				  Collections.<Attribute.ExceptionTableElement>emptyList(),
				  Collections.<Attribute>emptyList(),
				  instructions);
    }

    public static ClassDefinition compileClass(final List<AccessFlag> qualifiers,
					       final String name,
					       final String parent,
					       final List<String> parents,
					       final List<Field> fields,
					       final List<? extends Attribute> attributes,
					       final List<Method> methods) {
	return new ClassDefinition(qualifiers == null
				   ? asList(AccessFlag.Public, AccessFlag.Super, AccessFlag.Final)
				   : qualifiers,
				   name == null ? "pack.Test" : name,
				   parent == null ? "java.lang.Object" : parent,
				   parents == null ? Collections.<String>emptyList() : parents,
				   fields == null ? Collections.<Field>emptyList() : fields,
				   methods,
				   attributes == null ? Collections.<Attribute>emptyList() : attributes);
    }

}
